@@ -213,6 +213,7 @@ void usage()
     printf("                        -- Create segment 'name' and give it 'value'\n");
     printf("                           This option may be repeated.\n");
     printf("  --no_hash, -H         -- Do not calculate MD5, SHA1 and SHA256 of image.\n");
+    printf("  --multithreaded, -2   -- Calculate hashes in another thread\n");
 
 
     bold("\nError Recovery Options:\n");
@@ -301,6 +302,7 @@ static struct option longopts[] = {
     { "wipe",          no_argument,        NULL, 'w'},
     { "exec",          required_argument,  NULL, 'C'},
     { "ident",         no_argument,        NULL, 'i'},
+    { "multithreaded", no_argument,        NULL, '2'},
     {0,0,0,0}
 };
 
@@ -522,7 +524,9 @@ void process_config_questions(AFFILE *af,class imager *)
 
 	/* And write the response into the segment */
 	af_update_seg(af,segname,0,(const u_char *)val,strlen(val));
+#ifdef HAVE_LIBREADLINE
 	free(val);
+#endif
     }
     fclose(f);
 }
@@ -740,6 +744,7 @@ void process_option(class imager *im,char ch,char *optarg)
 	opt_sign_key_file = optarg;
 	opt_sign_cert_file = optarg;
 	break;
+    case '2': opt_multithreaded = 1;break;
 
     case 'h':
     case '?':
