@@ -37,7 +37,7 @@
  * The C++ imaging library.
  */
 
-int opt_threaded=0;
+int opt_multithreaded=0;
 
 imager::imager()
 {
@@ -85,11 +85,6 @@ imager::imager()
     memset(outfile,0,sizeof(outfile));
     memset(infile,0,sizeof(infile));
 
-    th_md5 = 0;
-    th_sha1 = 0;
-    th_sha256 = 0;
-
-    
     hash_invalid = false;
 
     last_sector_read = 0;
@@ -128,9 +123,9 @@ void imager::write_data(unsigned char *buf,uint64 offset,int len)
 
     if(!hash_invalid){
 	/* Update hash functions. */
-	th_md5->update(buf,len);
-	th_sha1->update(buf,len);
-	th_sha256->update(buf,len);
+	th_md5.update(buf,len);
+	th_sha1.update(buf,len);
+	th_sha256.update(buf,len);
     }
 
     /* Count the number of blank sectors.
@@ -617,9 +612,6 @@ void imager::hash_setup()
 {
     /* Set up the MD5 & SHA1 machinery */
     OpenSSL_add_all_digests();
-    th_md5 = new threaded_hash(EVP_get_digestbyname("md5"),opt_threaded);
-    th_sha1 = new threaded_hash(EVP_get_digestbyname("sha1"),opt_threaded);
-    th_sha256 = new threaded_hash(EVP_get_digestbyname("sha256"),opt_threaded);
 }
 
 
@@ -722,9 +714,9 @@ void imager::start_imaging2()
      ****************************************************************/
 
     /* Calculate the final MD5 and SHA1 */
-    th_md5->final();
-    th_sha1->final();
-    th_sha256->final();
+    md5 = th_md5.final();
+    sha1 = th_sha1.final();
+    sha256 = sha256.final();
 }
 
 
@@ -815,13 +807,13 @@ int imager::start_imaging()
     /* AFF Cleanup... */
     if(af){
 	if(hash_invalid==false){
-	    if(th_md5->valid() && af_update_seg(af,AF_MD5,0,th_md5->final(),th_md5->hash_size)){
+	    if(af_update_seg(af,AF_MD5,0,md5.final(),md5.SIZE)){
 		if(errno!=ENOTSUP) perror("Could not update AF_MD5");
 	    }
-	    if(th_sha1->valid() && af_update_seg(af,AF_SHA1,0,th_sha1->final(),th_sha1->hash_size)){
+	    if(af_update_seg(af,AF_SHA1,0,sha1.final(),sha1.SIZE)){
 		if(errno!=ENOTSUP) perror("Could not update AF_SHA1");
 	    }
-	    if(th_sha256->valid() && af_update_seg(af,AF_SHA256,0,th_sha256->final(),th_sha256->hash_size)){
+	    if(af_update_seg(af,AF_SHA256,0,sha256.final(),sha256.SIZE)){
 		if(errno!=ENOTSUP) perror("Could not update AF_SHA1");
 	    }
 	}
@@ -907,20 +899,12 @@ void imager::final_report()
     char print_buf[256];
     printf("\n");
     if(hash_invalid==false){
-	if(th_md5->valid()){
-	    printf("raw image md5:  %s\n",
-		   af_hexbuf(print_buf,sizeof(print_buf),th_md5->final(),th_md5->hash_size,opt_hexbuf));
-	}
-	
-	if(th_sha1->valid()){
-	    printf("raw image sha1: %s\n",
-		   af_hexbuf(print_buf,sizeof(print_buf),th_sha1->final(),th_sha1->hash_size,opt_hexbuf));
-	}
-	
-	if(th_sha256->valid()){
-	    printf("raw image sha256: %s\n",
-		   af_hexbuf(print_buf,sizeof(print_buf),th_sha256->final(),th_sha256->hash_size,opt_hexbuf));
-	}
+	printf("raw image md5:  %s\n",
+	       af_hexbuf(print_buf,sizeof(print_buf),md5.final(),md5.SIZE,opt_hexbuf));
+	printf("raw image sha1: %s\n",
+	       af_hexbuf(print_buf,sizeof(print_buf),sha1.final(),sha1.SIZE,opt_hexbuf));
+	printf("raw image sha256: %s\n",
+	       af_hexbuf(print_buf,sizeof(print_buf),sha256.final(),sha256.SIZE,opt_hexbuf));
     }
 
     if(imaging_failed){
